package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````,!8``#0```!HD0````0`!30`(``(
M`"@`%P`6``8````T````-````#0``````0````$```0````$`````P```#0!
M```T`0``-`$``!@````8````!`````$````!````````````````````\(D`
M`/")```%`````!````$```#(C0``R)T``,B=``!\`@``J`(```8`````$```
M`@```-"-``#0G0``T)T``/````#P````!@````0````$````3`$``$P!``!,
M`0``)````"0````$````!````%'E=&0```````````````````````````8`
M```0````4N5T9,B-``#(G0``R)T``#@"```X`@``!`````$````O;&EB+VQD
M+6UU<VPM87)M:&8N<V\N,0`$````%`````,```!'3E4`!B07]=4\?G""GJ])
M9GLU`-B;=581````30````@````(`````9`0`"5`!(`H@!`%H(90A("!``(+
M(`2-.(`208H$"`A-````3@```%(```!7````6````&````!A````8@``````
M``!D````90````````!F````9P```&H```````````````&O-.AJ?YI\ZM/O
M#L[>1RUOQ=\?+L6;MKB-\0[49-1\=E0\E"'_Y`[9<5@<^J%L8,+E/RRR`8MO
M0OK7A^)'Q@%8[Y=YF$_#F[OCDGQ5PSS29Z_,9H@'<--#1=7L,V+;[16,)<Q_
MJ9R;X*<""FH:GE"_VE<;H^#[20``````````````````````````>!``````
M```#``@```````"@`````````P`2``$``````````````!(````)````````
M```````2````$```````````````$0```/T!`````````````!$```"&`0``
M```````````2````%P``````````````$@```-8!`````````````!(````?
M```````````````2````)@``````````````$@````H"`````````````!(`
M``#B`0`````````````2````+P``````````````(````!0#````````````
M`"$```!'```````````````2````30``````````````$@```%0`````````
M`````!(```#3`@`````````````2````Z0(`````````````$@```%L`````
M`````````!(````E`@`````````````2````8@``````````````$@```*L"
M`````````````!(```!I```````````````2````<0``````````````$@``
M`,P"`````````````!(```!Y```````````````2````E`(`````````````
M$@```($``````````````!(```"*```````````````@````X@(`````````
M````$@```*8``````````````!(```"K```````````````2````L@``````
M````````$@```*,!`````````````!8```"R`@`````````````2````4@(`
M````````````$@```+L``````````````!(```!$`@`````````````2````
M6`,`````````````$@```+T"`````````````!$````3`P`````````````1
M````=@(`````````````$@`````#`````````````!(````5`P``````````
M```1````P@``````````````$@```,L``````````````!$```"4`0``````
M```````2````W0``````````````(@```.P``````````````"`````"`0``
M```````````2````LP``````````````$@```&("`````````````!(````'
M`0`````````````@````GP(`````````````$@```"$!`````````````!(`
M``#'`0`````````````2````)@$`````````````$@```(0"````````````
M`!(````L`0`````````````2````M@$`````````````$@```#H!````````
M`````!(```!+`0`````````````2````(`(`````````````$@```#$"````
M`````````!(```!1`0`````````````2````:P(`````````````$@```-L"
M`````````````!(```#X`@`````````````2````8`$`````````````$@``
M`!L"`````````````!(```!G`0`````````````2````;@$`````````````
M$@```!(#`````````````"$```!_`0`````````````2````8`0``'"@````
M````$``3``T#``!H$P``R`(``!(`"@#W`0```$@```0````2``L`F@,``#0N
M``"P!@``$@`*`'`$``#P-P``/`$``!(`"@!W`P``#"````0````2``H`%`0`
M`'@0```$````$@`(`+T#``#D-```#`,``!(`"@`:!```1*`````````0`!,`
M2`0``!`@``"D`@``$@`*`/4#``!$H````````!``$P"(`P``S"P``&@!```2
M``H`IP,``$0>``!8````$@`*`*\#``#4*0``H````!(`"@#3`P``*$4``(@!
M```2``H`Z`,``+0B```P````$@`*``$$``!PH````````!``$P`)!```="H`
M`'`````2``H`:P0``'"@````````$``3`#T#``!4%@``:````!(`"@`H!```
MY"(``*P!```2``H`W@,``$"@```$````$0`2`$$$``!$H````````!``$@#Z
M`P``,!8````````2``H`$00``+Q$``!L````$@`*`$8#``"H+```)````!(`
M"@!A`P``G!X``'`!```2``H`500``+!&``!0`0``$@`*`%\$``!PH```````
M`!``$P`T!```D"0``$0%```2``H``&]P96YD:7(`;65M8VUP`'-T9&5R<@!R
M96%L;&]C`&%C8V5S<P!S;G!R:6YT9@!?7V1E<F5G:7-T97)?9G)A;65?:6YF
M;P!L<V5E:P!G971P:60`<W1R8VUP`&UE;7-E=`!U;FQI;FL`;65M;6]V90!S
M=')N8VUP`'-T<G)C:'(`8VQO<V5D:7(`7TE435]D97)E9VES=&5R5$U#;&]N
M951A8FQE`&]P96X`<W1R<W1R`'9F<')I;G1F`'-T<F-H<@!R96%D;&EN:P!?
M7W-T86-K7V-H:U]G=6%R9`!?7V-X85]F:6YA;&EZ90!?7W)E9VES=&5R7V9R
M86UE7VEN9F\`97AI=`!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`')E860`
M<FUD:7(`7U]S=&%T7W1I;64V-`!?7V5R<FYO7VQO8V%T:6]N`&UK9&ER`%]?
M;'-T871?=&EM938T`&UE;6-P>0!S=')L96X`7U]S=&%C:U]C:&M?9F%I;`!G
M971U:60`4&5R;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET,P!03%]C=7)R96YT
M7V-O;G1E>'0`4&5R;%]A=&9O<FM?;&]C:P!P97)L7V-O;G-T<G5C=`!097)L
M7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X=`!?9FEN:0!03%]D;U]U;F1U
M;7``4&5R;%]N97=84U]F;&%G<P!P97)L7V9R964`4&5R;%]M9U]S970`4&5R
M;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C:'!V
M`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!B;V]T7T1Y;F%,
M;V%D97(`<&5R;%]P87)S90!097)L7W-A9F5S>7-M86QL;V,`<&5R;%]A;&QO
M8P!03%]M96UO<GE?=W)A<`!S=')C<'D`<F5A9&1I<@!S=')T;VL`<W1R9'5P
M`'!T:')E861?871F;W)K`'-P<FEN=&8`7U]L:6)C7W-T87)T7VUA:6X`7U]?
M96YV:7)O;@!L:6)P97)L+G-O`&QI8F,N;75S;"UA<FUH9BYS;RXQ`%]S=&%R
M=%]C`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C=7)R96YT7V5X
M96-?<')O8P!P87)?8W5R<F5N=%]E>&5C`'!A<E]S971U<%]L:6)P871H`'!A
M<E]M:W1M<&1I<@!X<U]I;FET`'!A<E]E;G9?8VQE86X`6%-?26YT97)N86QS
M7U!!4E]"3T]4`'-H85]U<&1A=&4`;7E?<&%R7W!L`'!A<E]B87-E;F%M90!?
M7V)S<U]S=&%R=`!?7V5N9%]?`'!A<E]D:64`<VAA7VEN:70`7U]B<W-?<W1A
M<G1?7P!P87)?9&ER;F%M90!P87)?:6YI=%]E;G8`7V5D871A`'!A<E]F:6YD
M<')O9P!S:&%?9FEN86P`7U]B<W-?96YD7U\`7V5N9`!P87)?8VQE86YU<``O
M=7-R+VQI8B]P97)L-2]C;W)E7W!E<FPO0T]210```,B=```7````S)T``!<`
M``"\GP``%P```,B?```7````U)\``!<`````H```%P```!"@```7````%*``
M`!<````<H```%P```""@```7````)*```!<````HH```%P```"R@```7````
M-*```!<````XH```%P```$"@```7````P)\``!4%``#$GP``%08``,R?```5
M#@``T)\``!4?``#8GP``$R0``-R?```5*@``X)\``!4N``#DGP``%3```.B?
M```5,@``[)\``!4S``#PGP``%3<``/2?```5/```^)\``!4^``#\GP``%4(`
M`,R>```6`P``T)X``!8$``#4G@``%@<``-B>```6"```W)X``!8)``#@G@``
M%@H``.2>```6"P``Z)X``!8,``#LG@``%@T``/">```6#@``])X``!80``#X
MG@``%A$``/R>```6$@```)\``!83```$GP``%A0```B?```6%0``#)\``!86
M```0GP``%A<``!2?```6&```&)\``!89```<GP``%AH``""?```6&P``))\`
M`!8<```HGP``%AT``"R?```6'@``,)\``!8@```TGP``%B$``#B?```6(@``
M/)\``!8C``!`GP``%B4``$2?```6)@``2)\``!8G``!,GP``%B@``%"?```6
M*0``5)\``!8L``!8GP``%BT``%R?```6+P``8)\``!8Q``!DGP``%C(``&B?
M```6,P``;)\``!8T``!PGP``%C4``'2?```6-@``>)\``!8X``!\GP``%CD`
M`("?```6.@``A)\``!8[``"(GP``%CT``(R?```6/P``D)\``!9```"4GP``
M%D$``)B?```60P``G)\``!9$``"@GP``%D4``*2?```61@``J)\``!9'``"L
MGP``%D@``+"?```620``M)\``!9*``"XGP``%DP```%`+>D!0+WH'O\OX03@
M+>4$X)_E#N"/X`CPON4LC@```,:/X@C*C.(L_KSE`,:/X@C*C.(D_KSE`,:/
MX@C*C.(<_KSE`,:/X@C*C.(4_KSE`,:/X@C*C.(,_KSE`,:/X@C*C.($_KSE
M`,:/X@C*C.+\_;SE`,:/X@C*C.+T_;SE`,:/X@C*C.+L_;SE`,:/X@C*C.+D
M_;SE`,:/X@C*C.+<_;SE`,:/X@C*C.+4_;SE`,:/X@C*C.+,_;SE`,:/X@C*
MC.+$_;SE`,:/X@C*C.*\_;SE`,:/X@C*C.*T_;SE`,:/X@C*C.*L_;SE`,:/
MX@C*C.*D_;SE`,:/X@C*C.*<_;SE`,:/X@C*C.*4_;SE`,:/X@C*C.*,_;SE
M`,:/X@C*C.*$_;SE`,:/X@C*C.)\_;SE`,:/X@C*C.)T_;SE`,:/X@C*C.)L
M_;SE`,:/X@C*C.)D_;SE`,:/X@C*C.)<_;SE`,:/X@C*C.)4_;SE`,:/X@C*
MC.),_;SE`,:/X@C*C.)$_;SE`,:/X@C*C.(\_;SE`,:/X@C*C.(T_;SE`,:/
MX@C*C.(L_;SE`,:/X@C*C.(D_;SE`,:/X@C*C.(<_;SE`,:/X@C*C.(4_;SE
M`,:/X@C*C.(,_;SE`,:/X@C*C.($_;SE`,:/X@C*C.+\_+SE`,:/X@C*C.+T
M_+SE`,:/X@C*C.+L_+SE`,:/X@C*C.+D_+SE`,:/X@C*C.+<_+SE`,:/X@C*
MC.+4_+SE`,:/X@C*C.+,_+SE`,:/X@C*C.+$_+SE`,:/X@C*C.*\_+SE`,:/
MX@C*C.*T_+SE`,:/X@C*C.*L_+SE`,:/X@C*C.*D_+SE`,:/X@C*C.*<_+SE
M`,:/X@C*C.*4_+SE`,:/X@C*C.*,_+SE`,:/X@C*C.*$_+SE`,:/X@C*C.)\
M_+SE`,:/X@C*C.)T_+SE`,:/X@C*C.)L_+SE`,:/X@C*C.)D_+SE`,:/X@C*
MC.)<_+SE`,:/X@C*C.)4_+SE`<J@XW!`+>D,P$W@R`^,Y5C"G^4HT$WB5#*?
MY1P`C>48$(WE%""-Y0S`C^`#,)SG&!"-XA0@C>(<`(WB-%*?Y0`PD^4D,(WE
M`#"@XZ;__^LD(I_E!5"/X`(@E><<,I_E#""-Y0,PE><"$*#A`P"@X1`PC>57
M___K!#*?Y0,PE><`0-/E``!4XT\```IP+QWN\#&?Y1P`G>4#,)_G`T"`X@,@
MDN<$`(#BUC/2Y0<!<.,#,(/CUC/"Y6```(H``:#AF___ZP`PH.&\(9_E&!"=
MY0(@C^``8)+EL,&?Y;!1G^6PX9_E'""=Y0``D>4,P(_@!5"/X`[@C^`!`%+C
M84"#Z`0PC.54``#:!`!!X@S`@^("`8#@!."QY0$`4.$$X*SE^___&@/`@N(`
MX*#C:%&?Y6@1G^4%4(_@#`"5Y00@H.$`X(WE`1"/X`SA@^<\___K``!0XRD`
M``I$49_E(&"-X@50C^`,`)7E5O__ZP!`H.$P`9_E!A"@X0``C^#5``#K``!0
MXR````H<,9_E`S"/X`P`D^6-___KZO[_ZPPAG^7,,)_E`B"/X`,PDN<`()/E
M)#"=Y0(@,^``,*#C*@``&@0`H.$HT(WB<("]Z"[__^O<()_E``!0XP(@C^`,
M`(+E'P``"EC__^MP+QWNQ#"?Y0,PG^<#,)+GKD;#Y:/__^H,`)7E1___Z]+_
M_^H(`)7E``!0XP$```J:"`#KV?__ZI0`G^4&$*#A``"/X*D``.L``%#C"`"%
MY=+__PKU___J>#"?Y7@`G^4#,)7G``"/X`,0H.$,,(WES/[_ZP3`H..P___J
M`0"@XRC__^M=___K*(L``"0!``#\B@``/`$``#@!```$`0``T(L```",```$
MC```2#<``$@W``"\BP``Y`@``)"+``!H-```9(L``*R)```8BP``>(H``%0S
M```<`0``+#4```"PH.,`X*#C$!"?Y0$0C^`-`*#A#\#`XPS0H.$```#KC(<`
M``3@+>4`X*#C`""@X400G^5$`)_E`1"/X```D><4T$WB.#"?Y0@`C>4#,)'G
M,,"?Y0PPC>4$X(WE#!"1YP`PH.$`$(WE#`"=Y000DN3E_O_K%-"-X@3PG>10
MB```%`$``/P````(`0``+`"?Y2PPG^4``(_@`S"/X```4^$@,)_E`S"/X![_
M+P$8()_E`C"3YP``4^,>_R\!$_\OX7B)``!TB0``Y(<``!`!```X`)_E.#"?
MY0``C^`#,(_@`#!#X*,?H.%#$8'@)#"?Y<$0L.$#,(_@'O\O`1@@G^4",)/G
M``!3XQ[_+P$3_R_A-(D``#")``"4AP``,`$```'*H.,00"WI#,!-X/@/C.5D
M,)_E9$"?Y0,PC^``,-/E!$"/X```4^,0@+T84#"?Y0,PE.<``%/C`@``"D0P
MG^4#`)_GL?[_Z\?__^LX,)_E`S"4YP``4^,"```*+`"?Y0``C^!2_O_K`2"@
MXR`PG^4#,(_@`"##Y1"`O>C4B```2(<``"@!``!HB```#`$``#1R``!\B```
M0#"?Y4`@G^4#,(_@`C"3YP``4^,*```*`<J@XQ!`+>D,P$W@^`^,Y2`0G^4@
M`)_E`1"/X```C^"1_O_K$$"]Z+3__^JS___JR(8``"P!```HB```R'$```'*
MH./P1RWI#,!-X.`/C.7(,)_E`(!0X@,PC^`K```*O""?Y0(PD^<`D)/E``!9
MXR@```H`4-CE`7"@X0``5>,]`%43`5"@$P!0H`,1```:`$"9Y0``5.,,```*
M"6"@X04@H.$($*#A!`"@X37^_^L``%#C`@``&@4PU.<]`%/C"P``"@1`MN4`
M`%3C\___&@0`H.'PA[WH"%"@X0$P]>4``%/C/0!3$_O__QH(4$7@YO__Z@E@
M1N`!4(7B1F&@X05`A.`$`*#A`&"'Y?"'O>@(0*#A[?__Z@E`H.'K___J8(8`
M`"`!```!RJ#C$$`MZ0S`3>!8#XSEC""?Y8PPG^4"((_@H-!-X@,PDN<-$*#A
M`#"3Y9PPC>4`,*#C`$"@X67^_^L``%#C``"@$P0``!H0,)WE#SH#X@H*4^,!
M"5,3"@``"D@@G^5`,)_E`B"/X`,PDN<`()/EG#"=Y0(@,^``,*#C!P``&J#0
MC>(0@+WH`A"@XP0`H.'%_?_K$`]OX:`"H.'N___J8/[_ZWB%```D`0``+(4`
M``'*H./P0"WI#,!-X$@/C.54(9_E5#&?Y0(@C^`#,)+GI-!-X@!04.(`,)/E
MG#"-Y0`PH.,"```*`##5Y0``4^,*```:*"&?Y2`QG^4"((_@`S"2YP`@D^6<
M,)WE`B`SX``PH.,_```:I-"-XO"`O>B2_?_K`$!0XO'__PH$`*#AM?W_ZP``
M4.,H```*$S#0Y1-@@.(N`%/C`@``&@$PUN4``%/C]/__"A,PT.4N`%/C(P``
M"@4`H.$K_O_K`'"@X08`H.$H_O_K``"'X`(`@.*P_?_K!C"@X0!@H.&4$)_E
M!2"@X0$0C^`6_O_K!@"@X0T0H.'^_?_K`0!PXP8`H.$#```*$#"=Y0\Z`^(!
M"5/C$@``"IS]_^L&`*#A_?W_ZP0`H.&,_?_K``!0X];__QH$`*#AJ?W_ZP4`
MH.'I_?_KO___Z@$PUN4N`%/CV/__&@(PUN4``%/CQ___"M3__^JF___KZ___
MZ@+^_^O(A```)`$``)2$``#8+0```<J@X_!'+>D,P$W@V`^,Y0%`H.$0(I_E
M$#*?Y0(@C^`#,)+G"-!-X@`PD^4$,(WE`#"@XP`PT>4`4*#A/0!3XP%`@0($
M`*#AZ/W_ZPT0H.$`8*#A!0"@X2/__^O0<9_E`)!0X@=PC^!````*W_W_ZP``
M5N$W``":N#&?Y0"`G>4#<)?G"(&@X0`PU>4``%/C/0!3$P$PH!,`,*`#!0``
M"@4PH.$!(//E``!2XST`4A/[__\:!3!#X`(`AN(#`(#@`&"7Y53]_^L``%#C
M"`"&YQ4```H%`*#A`#"7Y0@0D^<!,-#D/0!3XP``4Q,`,,'E!@``"@$@@>(!
M,-#D`A"@X3T`4^,``%,3`3#"Y/G__QH],*#C`2"@X0`PP>4!,-3D``!3XP$P
MXN7[__\:""&?Y?@PG^4"((_@`S"2YP`@D^4$,)WE`B`SX``PH.,U```:"-"-
MXO"'O>@!D$GB`3#4Y```4^,!,.GE^___&N[__^K`,)_E`W"7YP"`E^4`,)CE
M``!3XR0```H(,*#A!""SY0D0H.$``%+C`9")XOK__QH#$('B`1&@X9`PG^4#
M,(_@`""3Y0``4N,/```:`2"@XP$`H.$`((/E$_W_ZP"@4.+5__\*"!"@X0F!
MH.$((*#A$/W_ZP"@A^4`,*#C`)"-Y0&0B>(),8KGHO__Z@@`H.'8_/_K``!0
MXP"@H.$``(?EQ?__"@F!H.'R___J`Y"@X0@0H./?___J<_W_ZTB#```D`0``
M`(,``"`!```P@@``6(,```'*H.,00"WI#,!-X.@/C.5P3QWN;!"?Y6PPG^4!
M$(_@`S"1YQ#03>)@`)_E##"-Y0,@H.$``)_G5#"?Y500G^4``)3G`S"/X`$0
MC^!'_?_K`,"@XT``G^5`,)_E``"?YSP@G^4\$)_E`S"/X```E.<"((_@"!"-
MZ`$0C^"T_/_K$-"-XA"`O>@$@0``-`$```2"``!D:P``O"H``-R!``"<+0``
MU!8``*@J```\$)_E/#"?Y0$0C^`#,)'G<,\=[@,@H.$(T$WB*`"?Y00PC>4`
M`)_G(#"?Y2`0G^4``)SG`S"/X`$0C^`(T(WB'_W_ZFR````T`0``:($``,AJ
M```@*@```<J@XW!`+>D,P$W@``",Y0'*3.(``(SE*``,Y30AG^4T,9_E`MI-
MXAC03>("((_@`S"2YP(:C>(4$('B`#"3Y0`P@>4`,*#CC/S_ZPS!G^4,09_E
M#"&?Y0S`C^`,8(WB`#"@X000H.$&`*#A`B"/X`#`C>5R_/_K`3"`X@0`4^$P
M``"*`0!PXR\```H!6HWB$%"%X@$JH.,%$*#A!@"@X<'\_^L`0%#B)P``N@$`
MA.*'_/_K`#!0XB,```H%`%/A`@``*@0@@^`"`%7A'0``.@4`4^$8``"*A""?
MY0(`5.$8``"*!""@X0,`H.$%$*#AYOS_ZP`@H.,`,*#A!"#`YV00G^50()_E
M`1"/X`(*C>("()'G%`"`X@`0DN4`()#E`1`RX``@H.,)```:`P"@X0+:C>(8
MT(WB<("]Z`0@A>`"`%/AX___*O``\.<`,*#CZO__ZM;\_^OP?P``)`$``.@I
M```!$```R"D``!1_``"B___J`<J@X_!/+>D,P$W@``",Y=``#.58PI_E6"*?
MY4+=3>(LT$WB#,"/X`!0H.%(`I_E`B"<YT(]C>((<(WB`6"@X0``C^`'$*#A
M)#"#X@`@DN4`((/E`""@X_3]_^LO$*#C`$"@X04`H.%C_/_K``!0XQ(```H$
M`I_E!1"@X0``C^"O_O_K!0"@X?0AG^7D,9_E`B"/X$(=C>(#,)+G)!"!X@`@
MD^4`,)'E`B`SX``PH.-M```:0MV-XBS0C>+PC[WH!@"@X3K\_^NX$9_E`1"/
MX(O\_^L`H%#BY?__"@`PVN6D@9_EJ)"-X@``4^,(@(_@!&!)XC\```H``%3C
M!```"@H0H.$$`*#A`OS_ZP``4.,O```*"@"@X87\_^L!,$#B`S"*X`,`6N$`
M(*#A`+"@X0`0H#,`((HP`3"*,@,``#H(``#J`@!3X0`0PN4"```*`<!RY2\`
M7./Y__\*"@"@X7/\_^L`L*#A!0"@X7#\_^L+`(#@`0"`X@$*4..\__\J",&?
MY0HPH.$,P(_@"""@X0$:H.,&`*#A!%"-Y0#`C>7*^__K`0"`X@$*4.,O``"*
M!Q"@X08`H.$__/_K``!0XP,``!J0,!GE#SH#X@()4^,5```*N!"?Y0``H.,!
M$(_@1_S_ZP"@4.*A__\*`##:Y0``4^.___\:``!4XQ8```H`,-3E+@!3XP,`
M``J$H)_E`;"@XPJ@C^#2___J`3#4Y0``4^/J__\*]___Z@$0H.,&`*#AHOO_
MZP``4./D__\:5`"?Y080H.$``(_@//[_ZP8`H.'6^__KBO__ZCR@G^4!L*#C
M"J"/X+[__^HS_/_K\`#PYX1^```D`0``E"@``&0H```8?@``)"@```@H``!T
M)P``%"<``+PF``"8)@``;"8```'*H.,00"WI#,!-X/@/C.4O$*#C`$"@X;/[
M_^L``%#C`4"`$@0`H.$00+WHM_O_Z@'*H.,P0"WI#,!-X```C.48``SE="&?
MY70QG^4!VDWB`B"/X`S03>(!&HWB`S"2YP!04.($$('B`#"3Y0`P@>4`,*#C
M,```"@`PU>4``%/C+0``"@'\_^L!`(#B`0I0XSH``(H$0(WB!1"@X00`H.&.
M^__K!`"@X?C[_^L!`$#B``"$X`0`4.$'``":`""@XP(``.H$`%#A`2#`Y0(`
M``H!,%#D+P!3X_G__PHO$*#C!`"@X8#[_^L``%#C)0``"@0`4.$`,*"#`##`
MA00`H.&"^__KO""?Y;0PG^4"((_@`1J-X@,PDN<$$('B`""3Y0`PD>4"(#/@
M`#"@XR(``!H!VHWB#-"-XC"`O>B(()_E?#"?Y0(@C^`!&HWB`S"2YP00@>(`
M()/E`#"1Y0(@,^``,*#C%```&F``G^4``(_@`=J-X@S0C>(P0+WH8_O_Z@``
MH./>___J1""?Y3`PG^4"((_@`1J-X@,PDN<$$('B`""3Y0`PD>4"(#/@`#"@
MXR``GP4``(\`[/__"K;[_^NT>P``)`$``/AZ``#`>@``P"0``'1Z``!X)```
M`<J@XW!`+>D,P$W@Z`^,Y<0DG^7$-)_E`B"/X,!4G^4#,)+GO&2?Y0C03>(%
M4(_@`#"3Y00PC>4`,*#C!F"/X`U`H.$$$*#A!@"@X=?\_^L``%#C#@``"HPT
MG^4`$)WE`S"5YP`@D^4!,8+@!`"3Y0``4.,!`8+G\?__"@0P@^($()/E``!2
MXP0@@^3[__\:Z___ZE1DG^4&8(_@!!"@X08`H.'!_/_K``!0XPX```HT-)_E
M`!"=Y0,PE><`()/E`3&"X`0`D^4``%#C`0&"Y_'__PH$,(/B!""3Y0``4N,$
M((/D^___&NO__^H`9)_E!F"/X`00H.$&`*#AJ_S_ZP``4.,.```*W#.?Y0`0
MG>4#,)7G`""3Y0$Q@N`$`)/E``!0XP$!@N?Q__\*!#"#X@0@D^4``%+C!""#
MY/O__QKK___JK&.?Y09@C^`$$*#A!@"@X97\_^L``%#C#@``"H0SG^4`$)WE
M`S"5YP`@D^4!,8+@!`"3Y0``4.,!`8+G\?__"@0P@^($()/E``!2XP0@@^3[
M__\:Z___ZEACG^4&8(_@!!"@X08`H.%__/_K``!0XPX```HL,Y_E`!"=Y0,P
ME><`()/E`3&"X`0`D^4``%#C`0&"Y_'__PH$,(/B!""3Y0``4N,$((/D^___
M&NO__^H$8Y_E!F"/X`00H.$&`*#A:?S_ZP``4.,.```*U#*?Y0`0G>4#,)7G
M`""3Y0$Q@N`$`)/E``!0XP$!@N?Q__\*!#"#X@0@D^4``%+C!""#Y/O__QKK
M___JL&*?Y09@C^`$$*#A!@"@X5/\_^L``%#C#@``"GPRG^4`$)WE`S"5YP`@
MD^4!,8+@!`"3Y0``4.,!`8+G\?__"@0P@^($()/E``!2XP0@@^3[__\:Z___
MZEQBG^4&8(_@!!"@X08`H.$]_/_K``!0XPX```HD,I_E`!"=Y0,PE><`()/E
M`3&"X`0`D^4``%#C`0&"Y_'__PH$,(/B!""3Y0``4N,$((/D^___&NO__^H(
M8I_E!F"/X`00H.$&`*#A)_S_ZP``4.,.```*S#&?Y0`0G>4#,)7G`""3Y0$Q
M@N`$`)/E``!0XP$!@N?Q__\*!#"#X@0@D^4``%+C!""#Y/O__QKK___JM&&?
MY09@C^`$$*#A!@"@X1'\_^L``%#C#@``"G0QG^4`$)WE`S"5YP`@D^4!,8+@
M!`"3Y0``4.,!`8+G\?__"@0P@^($()/E``!2XP0@@^3[__\:Z___ZF!AG^4&
M8(_@!!"@X08`H.'[^__K``!0XPX```H<,9_E`!"=Y0,PE><`()/E`3&"X`0`
MD^4``%#C`0&"Y_'__PH$,(/B!""3Y0``4N,$((/D^___&NO__^H,`9_E!!"@
MX0``C^#F^__K`!!0X@(```KX`)_E``"/X*;\_^OP`)_E!!"@X0``C^#=^__K
M`!!0X@(```K<`)_E``"/X)W\_^O4`)_E!!"@X0``C^#4^__K`!!0XA(```K`
M`)_E``"/X)3\_^NX()_E9#"?Y0(@C^`#,)+G`""3Y00PG>4"(#/@`#"@XQ``
M`!J8$)_EF`"?Y0$0C^```(_@"-"-XG!`O>B$_/_JA`"?Y000H.$``(_@N_O_
MZP`04.+I__\*<`"?Y0``C^![_/_KY?__ZGCZ_^L0>@``)`$``/QY``!$)```
M(`$``/0C``"D(P``6",```@C``#`(@``!"(``!PB``#0(0``A"$``+`@``#<
M(```L"```,P@``#,(```R"```.P?``"P=0``""(```@@``!T(```^!\```'*
MH.,$X"WE#,!-X/`/C.5X()_E>#"?Y0(@C^!T`)_E#-!-X@,PDN<-$*#A``"/
MX``PD^4$,(WE`#"@XXK[_^L``%#C!0``"@``T.4``%#C,`!0$P$`H`,``*`3
M`0`@XC0@G^4H,)_E`B"/X`,PDN<`()/E!#"=Y0(@,^``,*#C`0``&@S0C>($
M\)WD.OK_Z\QT```D`0``5!\``'QT```!RJ#C#P`MZ03@+>4,P$W@\`^,Y40@
MG^5$,)_E`B"/X`,PDN<,T$WB`#"3Y00PC>4`,*#C+#"?Y2P`G^44((WB`S"/
MX``@C>4`,)/G$!"=Y0``D^7&^?_K_P"@X^CY_^LH=```)`$```1T`````0``
M`,"@X_!'+>D!Z*#C#,!-X`[@3.`!RDSB``",Y0X`7.'[__\:.``.Y0(0H.-T
MX9_E=,&?Y0'83>(8T$WB#N"/X`S`GN<!2(WB`""@XP`PH.,`P)SE%,"$Y0#`
MH.,`$(WE`("@X7#Y_^L!8%#B`'#!XL<OH.''/R;@`C!3X',P_^8","/@`C!3
MX`(@PN`#8%;@`G#'X```5^,40(3B-P``N@B1G^4,4(WB`!"@XP8@H.$',*#A
M"`"@X0`0C>5:^?_K`0!QXP$`<`,R```*"2"@X040H.$(`*#AN?G_ZP$`<.,I
M```*!P!0XQ\``)H(`$#B`$"5X!P``"JTH)_E"J"/X`(``.H!0$3B!0!4X18`
M`#H((*#C"A"@X00`H.$G^?_K``!0X_;__QH%0$3@!@"4X,0?I^!\()_E;#"?
MY0(@C^`!R(WB`S"2YQ3`C.(`()/E`#"<Y0(@,^``,*#C$```&@'8C>(8T(WB
M\(>]Z`%H5N(`<,?B`0!WXP$(=@/)__\:``#@XP`0H.'I___J*`"?Y0``C^!]
M___K(`"?Y0``C^!Z___KL/G_ZYAS```D`0``"``!`!QT``"8<@``;!T``%`=
M```!RJ#C$$`MZ0S`3>#X#XSEI_G_ZUCY_^L``%#C``"0%1"`O>@!RJ#C\$`M
MZ0S`3>#8#XSE+"&?Y2QAG^4L,9_E`B"/X!303>(#,)+G!F"/X`!0H.$&`*#A
M"!"-X@`PD^4,,(WE`#"@X\KZ_^L`0%#B`@``"@`PU.4``%/C#@``&NP@G^7D
M,)_E`B"/X`,PDN<`()/E##"=Y0(@,^``,*#C+P``&@40H.'(`)_E``"/X!30
MC>+P0+WH>_O_Z@40H.$;^?_K``!0XPH```JH()_EF#"?Y0(@C^`#,)+G`""3
MY0PPG>4"(#/@`#"@XQP``!H4T(WB\("]Z`4`H.%F^?_K`'"@X00`H.%C^?_K
M``"'X`(`@.+K^/_K8#"?Y6`0G^4%(*#A`S"/X`$0C^``0(WE`$"@X4_Y_^M(
M()_E+#"?Y0(@C^`#,)+G`""3Y0PPG>4"(#/@`#"@XP00H`$&`*`!TO__"D_Y
M_^O0<0``^!P``"0!``"(<0``F!P``#QQ```T&P``-!L``-!P```!RJ#C\$\M
MZ0S`3>#`#HSE1]]-XLB@C>(*X*#A`!:?Y0#&G^4`)I_E`1"/X`(@D><,P(_@
M##",XAB0C.*P4(WB`""2Y10AC>4`(*#C`'"@X0<`D^@'`(7H#P"YZ`\`KN@#
M`)GH,,",XKQ`C>(#`([H!P"<Z`<`A.BP!9_E&&"-X@80H.$``(_@7_K_ZZ"%
MG^4`D%#B"("/X`(```H`,-GE``!3XPD!`!H>^?_KS_C_ZP``4.-R```*`)"0
MY0``6>-O```*"0"@X1#Y_^N``*#A`0"`XICX_^L`(-GE`$"@X0``4N,4`(WE
M"```"D2UG^4+L(_@!`"@X0L0H.'Z^/_K`2#YY0)`A.(``%+C^/__&B0%G^4`
M`(_@`@``Z@0`NN4``%#C#0``"@80H.$V^O_K`$!0XOC__PH`,-3E``!3X_7_
M_PIJ^O_K``!0X_+__PH$`*#AC?C_ZP!`4.(,```:!$"5Y```5.,)```*`##4
MY0``4^/%```*!`"@X5SZ_^L``%#C\?__&@1`E>0``%3C]?__&@0`H.'<^/_K
M%)"=Y0!0H.$)`*#AV/C_ZP!0A>`!6X7B!%"%X@4`H.%>^/_K!)"-Y0"0H.%P
M-)_E<!2?Y0,PC^``,(WE:#2?Y00@H.$#,(_@`1"/X+_X_^L'':#C"0"@X:WX
M_^L!`'#C`P``&J?X_^L`P)#E$0!<XZ4``!H&$*#A"0"@X:KX_^L`0%#B+```
M"B`DG^4@%)_E`@"8YPDPH.$`()?E``"0Y0$0C^""^/_K`%"@XP0DG^78,Y_E
M`B"/X`,PDN<`()/E%#&=Y0(@,^``,*#CZ0``&@4`H.%'WXWB\(^]Z$3X_^L`
MD%#BA```&@0`E.0``%#C"0``"@80H.'<^?_K`#!0XOC__PH`,-/E``!3X_+_
M_QH$`)3D``!0X_7__QH-`*#C'OC_ZY"3G^53(*#C`$"@X0F0C^`4`(WEA/__
MZB@PG>4/.@/B`0E3X\[__QHPH)WEC?C_ZP``6N'*__\:*#"=Y8,[H.&C.Z#A
M!PU3X\7__QH%`*#A"?C_ZP!0H.$\`Y_E!A"@X0``C^"X^?_K`!!0XG4```H`
M`)?EJ/O_ZP"@4.)Q```*"@"@X7'X_^L#`%#C`("@X0P``)H$$Y_E!`!`X@``
MBN`!$(_@XO?_ZP``4.,%```:!`!8XY<```H(@(K@!3!8Y2\`4^.3```*U`*?
MY080H.$``(_@G/G_ZP``4.,#```*`##0Y3``4^,``%,3!```&@`0H.,*`*#A
M]_?_ZP!@4.)2```:G!*?Y9P"G^4!$(_@``"/X%'Z_^O"]__KC"*?Y8PRG^6,
M$I_E`B"/X(B"G^6(<I_EB&*?Y04`C>@#,(_@"2"@X04`H.$!$(_@-OC_ZPB`
MC^`'<(_@!F"/X`T``.H?^/_K`#"0Y1$`4^,.```:K/?_ZP#`H.$!0(3B"#"@
MX0D@H.$'$*#A!0"@X5``C>D`P(WE)/C_ZP<=H.,%`*#A$OC_ZP$`<./L__\*
M"0"@X1'X_^L,`I_E!1"@X0``C^`F^O_K!0"@X8+^_^MM___J`T"@X3[__^H<
M^/_K@`"@X0$`@.(*___JG"&?Y=@1G^4"`)CG"3"@X0`@E^4!$(_@`,"-Y0``
MD.7@]__K7/__ZG#^_^NT(9_E3#&?Y0(@C^`#,)+G`""3Y10QG>4"(#/@`#"@
MXT8``!H)`*#A1]^-XO!/O>BA]__J`*"7Y8O__^KF_?_K`(!1X@!PH.&H__^Z
M`*"@XPH@4.(`,,CB!@"@X0"@C>7@L(WB9_?_ZP8@H.,+$*#A!@"@X<GW_^L&
M`%#C,```&C@QG^7@()WE`P!2X9?__QJT(-OA*#&?Y0,`4N&3__\:,B!7X@`P
MR.(&`*#A`*"-Y>A`C>)3]__K*""@XP8`H.$$$*#AM??_ZR@`4.,<```:\""?
MY?`PG^7P$)_E`B"/X`0@C>4%`*#A"2"@X0!`C>4#,(_@`1"/X!"AS>7%]__K
MI/__Z@1PE^4``%?C:/__"@<`H.'(]__K`P!0XV3__YJL$)_E!`!`X@``A^`!
M$(_@.O?_ZP``4.,'H*`!7/__ZL#W_^N,`)_E``"/X(;]_^M<<```F'$``"0!
M```L&@``\&\``.`:``!8&@``%!H``/09``#X&`````$``.P9```T;@``_!@`
M`%P9```D&0``D!<``#09``!0%P``@!D``-P6``"H&```R!8``*P8``!0&0``
M-!8``#`7``"H:P```$-!0TA%``"X%P``%!4``-@6``",%@``>!8```'*H./P
M0"WI#,!-X.`/C.6,(I_EC#*?Y0(@C^`#,)+G#-!-X@`PD^4$,(WE`#"@XW!/
M'>X-8*#A;#*?Y6P"G^4#,)_G!A"@X0-0E.<``(_@9##5Y64PQ>6_^/_K``!0
MXP(```H`,-#E,0!3XV(```K-^__K.#*?Y0,PG^<#4)3G,!*?Y04`H.$#,*#C
M`2"@XP$0C^`@]__K`%!0X@P```H,()7E$#*?Y0`0DN4#,)_G""*?Y0,`E.<"
M((_@'/?_ZPPPE>4`$)/E"#"1Y0$%$^-:```:Z!&?Y0,PH.,!$)_G`2"@XP$`
ME.?8$9_E`1"/X`GW_^L`4%#B"P``"L@!G^4&$*#A``"/X)/X_^L`(%#B/0``
M"K0QG^4,$)7E`S"?YP`0D>4#`)3G`??_ZZ`QG^6@$9_E`S"?YP$@H.,#4)3G
M`1"/X`4`H.&E]O_KB"&?Y0`0H.$"((_@!0"@X?3V_^L`(*#C=#&?Y70!G^4#
M,)_G!A"@X0,PE.<``(_@92##Y77X_^M<09_E``!0XP1`C^`(`(3E$```"@<=
MH.,7]__K`3"`XA$`4.,!`%,3-```BC0AG^7L,)_E`B"/X`,PDN<`()/E!#"=
MY0(@,^``,*#C*@``&@S0C>+P@+WH!`"4Y=K]_^L``%#C"`"$Y>G__QKX`)_E
M``"/X(7V_^L!,-#E``!3XYW__PJ8___JZ?G_ZP!P4.(.```*U#"?Y0P@E>4#
M,)_G`!"2Y0,`E.<'(*#AO_;_ZP<`H.'S]O_KNO__ZK`PG^4#,)_G`P"4YXCV
M_^N?___JH""?Y:`PG^4"((_@#!"5Y0,PG^<$()+E`!"1Y0`@DN4#`)3GK?;_
MZZK__^KY]O_K>""?Y0`PH.%T`)_E`B"/X`8`DND``(_@`!"1Y5OV_^N\:0``
M)`$``*QJ```(%```=&H``)05``!`:@``<!4``!!J``!$%0``"!,``-!I``"X
M:0``]!0``/@4``"`:0``B!(``.AI```<:```8!0``,QH``"H:```&&D``(AH
M``#D:```X!,```'*H.,P0"WI#,!-X.@/C.4,(9_E##&?Y0(@C^``0*#A!`&?
MY0,PDN<,T$WB#1"@X0``C^``,)/E!#"-Y0`PH.,"^/_K`#!0X@H```H`,-/E
M``!3XS``4Q,!,*`#`#"@$P$P(^(``%3C`#"@`P$P`Q(``%/C"@``&K`@G^6D
M,)_E`B"/X`,PDN<`()/E!#"=Y0(@,^``,*#C(```&@S0C>(P@+WH`##4Y0``
M4^/Q__\*!`"@X8[Z_^LO$*#C`%"@X3KV_^L``%#C`5"`$@4`H.$_]O_K6!"?
MY00@H.,!$(_@+/;_ZP``4./B__\:1""?Y3`PG^4"((_@`S"2YP`@D^4$,)WE
M`B`SX``PH.,#```:!`"@X0S0C>(P0+WH,?C_ZH[V_^NP9@``)`$``#01``!(
M9@``3!$``-1E`````````<J@X_!/+>D,P$W@D`Z,Y5@KG^58.Y_E`B"/X`,P
MDN=3WTWB`#"3Y40QC>4`,*#C#1"@X0!PH.$<((#B7`"`X@0PDN0S/[_F``!2
MX00PH>7Z__\:.`"=Y3S@G>5`,)WE!,"=Y0A0G>4(((WB0F^-X@```.H!4*#A
M`T"@X1PPDN4$$++E`3`CX``P(^`,,"/@XS^@X0(`5N$.`*#A!<"@X03@H.$X
M,(+E\?__&L0ZG^4,4)?E!!"=Y1!`E^4!$)?I`."7Y04@+.`#$('@!!"!X``@
M`N`%("+@"&"=Y>X=@>`"$('@8"$LX`-@AN`.(`+@!6"&X`P@(N!ND:#A!B""
MX`Q@G>5@@2G@`V"&X`&`".`,8(;@%+"=Y6"!*.#A+8+@$*"=Y0:`B.!A82G@
MXHV(X`)@!N`#L(O@8B&@X0FPB^`#H(K@"6`FX&&1(N!@H8K@")`)X`I@AN!A
MD2G@&*"=Y>AMAN`+D(G@:+$BX`.@BN`&L`O@YIV)X&&ABN!F$:#A`F`KX`I@
MAN`<H)WE:+$AX`.@BN`"((K@(*"=Y0FP"^`#H(K@Z6V&X&BABN!H@2O@:;$A
MX`*`B.`&L`O@YHV(X&8AH.$!8"O@"F"&X"2@G>5IL2+@`Z"*X`$0BN`HH)WE
M"+`+X`.@BN!IH8K@:9$KX.AMAN`!D(G@:!$BX`80`>`"$"'@"A"!X"R@G>7F
MG8G@`Z"*X&9AH.$"((K@,*"=Y6BQ)N`)L`O@`Z"*X&BABN!H@2O@Z1V!X`*`
MB.!I(2;@`2`"X`8@(N`*((+@-*"=Y>&-B.`#H(K@81&@X09@BN!IH2'@"*`*
MX#BPG>5IH2K@Z"V"X`:@BN!H82'@`["+X`)@!N!IL8O@`6`FX`M@AN`\L)WE
MXJV*X`.PB^!B(:#A`;"+X$`0G>5HD2+@`Q"!X`J0">#J;8;@:!&!X&B1*>!J
M@2+@!H`(X`*`*.`!@(C@1!"=Y0N0B>#FG8G@`Q"!X&9AH.%(L)WE`B"!X&H1
M)N`#L(O@"1`!X&JQB^!J$2'@3*"=Y>F-B.`"$('@:2$FX`.@BN`((`+@!B`B
MX`9@BN!0H)WEZ!V!X&B!H.$#,(K@::$HX`&@"N`+((+@::$JX.$M@N`&H(K@
M86$HX`)@!N!I,8/@"&`FX%BPG>4#8(;@%#B?Y520G>7BK8K@`["+X&(AH.$#
MD(G@8;&+X&$1(N`*$"'@"(")X.IMAN`!@(C@YIV(X%R`G>4#@(C@`H"(X&HA
M(N`&("+@`A"+X&`@G>5F8:#A`R""X&HA@N!JH2;@":`JX`J`B.!DH)WEZ1V!
MX`.@BN`&H(K@:6$FX`%@)N#AC8C@!B""X.AM@N!H()WE81&@X0,@@N!I(8+@
M:9$AX`B0*>`)D(K@;*"=Y>:=B>`#H(K@`:"*X&@1(>`&$"'@`2""X.D=@N!P
M()WE9F&@X0,@@N!H(8+@:($FX`F`*.`(@(K@=*"=Y>&-B.`#H(K@!J"*X&EA
M)N`!8";@!B""X.AM@N!X()WE81&@X0,@@N!I(8+@:9$AX`B0*>`)D(K@?*"=
MY>:=B>`#H(K@`:"*X&@1(>`&$"'@`2""X.D=@N"`()WE9F&@X0,@@N!H(8+@
M:($FX`F`*.`(@(K@A*"=Y>&-B.`#H(K@!J"*X&EA)N`!8";@!B""X.AM@N!A
ML:#AB""=Y6D1*^`($"'@`R""X&DA@N`!D(K@:*$KX`:@*N#FG8G@"B""X.FM
M@N"0()WEC!"=Y69AH.$#((+@`Q"!X&@A@N!H@2;@"8`HX`L0@>`($('@ZHV!
MX)00G>6DL)WE`Q"!X`80@>!I82;@"F`FX`8@@N#H;8+@F""=Y6JAH.$#((+@
M:2&"X&F1*N`(D"G@"1"!X)R0G>7F'8'@`Y")X`J0B>!HH2K@!J`JX`H@@N"@
MH)WE9F&@X0,PBN!H,8/@:($FX`&`*.#A+8+@"(")X&&1)N`"D"G@XHV(X`DP
M@^#HG8/@M#6?Y:B@G>5B(:#A`["+X`:PB^`#H(K@86&"X6&ABN`(8`;@81$"
MX`$0AN$+$('@:+&"X>D=@>!I8:#A";`+X&B1`N`)D(OAK+"=Y0J0B>"PH)WE
M`["+X`*PB^`#H(K@:"&&X6BABN`!(`+@:($&X.&=B>`(((+A88&&X0L@@N`)
M@`C@8;$&X`N`B.&TL)WEZ2V"X`.PB^`&L(O@N&"=Y6F1H.$*@(C@`V"&X&&A
MB>$"H`K@86&&X&$1">#BC8C@`1"*X6*AB>$+$('@"*`*X&*Q">`+H(KAO+"=
MY>@=@>`#L(O@";"+X,"0G>5H@:#A!F"*X`.0B>!BH8CA`:`*X&*1B>!B(0C@
MX6V&X`(@BN%AH8CA"R""X`:@"N!AL0C@"Z"*X<2PG>7F+8+@`["+X`BPB^#(
M@)WE9F&@X0F0BN`#@(C@8:&&X0*@"N!A@8C@81$&X.*=B>`!$(KA8J&&X0L0
M@>`)H`K@8K$&X`N@BN',L)WEZ1V!X`.PB^`&L(O@T&"=Y6F1H.$(@(K@`V"&
MX&*AB>$!H`K@8F&&X&(A">#AC8C@`B"*X6&AB>$+((+@"*`*X&&Q">`+H(KA
MU+"=Y>@M@N`#L(O@";"+X-B0G>5H@:#A!F"*X`.0B>!AH8CA`J`*X&&1B>!A
M$0C@XFV&X`$0BN%BH8CA"Q"!X`:@"N!BL0C@"Z"*X=RPG>4)D(K@X*"=Y>8=
M@>`#L(O@9F&@X0BPB^`#H(K@8H&&X6*ABN`!@`C@8B$&X.&=B>`"@(CA82&&
MX0N`B.`)(`+@8;$&X`L@@N'DL)WE"B""X.B@G>7IC8C@`["+X&F1H.$&L(O@
M`Z"*X&%AB>%AH8K@"&`&X&$1">#H+8+@`6"&X6@1B>$+8(;@`A`!X&BQ">`+
M$('A[+"=Y0H0@>#PH)WEXFV&X`.PB^!B(:#A";"+X`.@BN!HD8+A:*&*X`:0
M">!H@0+@Z#*?Y0B0B>'T@)WEYAV!X`N0B>`#@(C@9K&"X0&P"^`"@(C@9B$"
MX`(@B^$*((+@^*"=Y>&=B>`#H(K@81&@X6:ABN!F82'@"6`FX`:`B.#\8)WE
M`+&=Y0-@AN#I+8+@`6"&X&D1(>#BC8C@`A`AX`.PB^!B(:#A`1"*X&FQB^`$
MH9WE:9$BX`B0*>`)8(;@`Z"*X`B1G>7H'8'@`J"*X&@A(N#A;8;@`2`BX`.0
MB>!A$:#A:)&)X&B!(>`&@"C@"("*X`RAG>4"((O@`Z"*X.8M@N`!H(K@9A$A
MX`(0(>`!$(G@$)&=Y>*-B.`#D(G@8B&@X6:1B>!F82+@"&`FX`9@BN`4H9WE
MZ!V!X`.@BN`"H(K@:"$BX`$@(N`"((G@&)&=Y>%MAN`#D(G@81&@X6B1B>!H
M@2'@!H`HX`B`BN`<H9WEYBV"X`.@BN`!H(K@9A$AX`(0(>`!$(G@()&=Y>*-
MB.`#D(G@8B&@X6:1B>!F82+@"&`FX`9@BN`DH9WEZ!V!X`.@BN`"H(K@:"$B
MX`$@(N`"((G@*)&=Y>%MAN`#D(G@81&@X6B1B>!H@2'@!H`HX`B`BN`LH9WE
MYBV"X`.@BN`!H(K@9A$AX`(0(>`!$(G@,)&=Y>*-B.`#D(G@8B&@X6:1B>!F
M82+@"&`FX`9@BN`TH9WEZ!V!X`.@BN`"H(K@:"$BX`$@(N`"((G@.)&=Y>%M
MAN`#D(G@81&@X6B1B>!H@2'@!H`HX.8M@N`(@(K@XHV(X&A1A>`,4(?E/%&=
MY0-0A>`!4(7@9A$AX`(0(>`!$(G@Z!V!X&'!C.`(P(?E0,&=Y6(AH.$#,(S@
M9L$BX`)`A.`.,(/@",`LX&@A(N`!("+@9C&#X`Q0A>#A'87@`C"#X.$]@^!0
M()_E`#"'Y0$`@.`P,)_E`B"/X!!`A^4$`(?E`S"2YP`@D^5$,9WE`B`SX``P
MH.,!```:4]^-XO"/O>BK\__K<&4``"0!``"9>8):H>O9;MR\&X_6P6+*2%H`
M``'*H.,00"WI#,!-X/@/C.5@`*#C)O/_ZP`@H.,,>Y_M-,"?Y300G^4T0)_E
M-."?Y01[@.T(0(#E#."`Y0#`@.4$$(#E&""`Y5P@@.40@+WH`/`@X_#ATL,`
M`````2-%9XFKS>_^W+J8=E0R$`'*H./P1RWI#,!-X.`/C.4"4*#A`("@X10P
MD.6"(:#A`C"3X!@@D.44,(#E7`"0Y0$@@B*E+H+@``!0XP&@H.$8((CE''"(
M`A8```I`0&#B''"(X@4`5.$``(?@!4"@H0$`4.%"```J!#"`X`,`4>$$8($@
M.0``.@H0H.$$(*#A7_/_ZUPPF.4#,(3@0`!3XUPPB.7PA[T8"`"@X=G\_^L&
MH*#A!%!%X#\`5>,;``#:"D"@X5R0B.)`8(KB!`!7X2(``"H)`%3A)```.@:@
MH.$',*#A0."$X@#`E.4$`)3E"!"4Y0P@E.400(3B#@!4X0#`@^4$`(/E"!"#
MY0P@@^40,(/B\___&@@`H.%`4$7BO/S_ZS\`5>-`8(;BYO__R@H`5^$.```Z
M`@``F@4PBN`#`%?A"0``.@4@H.$*$*#A!P"@X2[S_^M<4(CE\(>]Z`:@H.'=
M__^:!@!7X=O__RKP`/#G!3"'X`,`6N'Q__\J^O__Z@1@@>"^__^:!@!0X;S_
M_RKU___J`<J@X_!!+>D,P$W@Z`^,Y7\@X.,4,)'E&&"1Y3-_O^:C,:#A/S`#
MX@'`@^(<@('B.`!<XP%`H.$`4*#A-F^_Y@,@R.<\``#:`!"@XT`@;.(,`(C@
MD/+_ZP0`H.&'_/_K.""@XP`0H.,(`*#ABO+_ZP0`H.'T9<3A@/S_ZP,PU.4$
M`*#A`##%Y;(PU.$!,,7E`#"4Y2,TH.$",,7E`#"4Y0,PQ>4',-3E!##%Y;8P
MU.$%,,7E!#"4Y2,TH.$&,,7E!#"4Y0<PQ>4+,-3E"##%Y;HPU.$),,7E"#"4
MY2,TH.$*,,7E"#"4Y0LPQ>4/,-3E###%Y;XPU.$-,,7E##"4Y2,TH.$.,,7E
M##"4Y0\PQ>43,-3E$##%Y;(QU.$1,,7E$#"4Y2,TH.$2,,7E$#"4Y1,PQ>7P
M0;WHP/+_Z@`0H.,,`(C@."!LXE/R_^O'___J`4`MZ0%`O>@>_R_A/@```$$`
M```,````00```!$```!!````)P```$$````V````00````,```!!````!@``
M`$$````5````00````\```!!````#@```$$````F````00```!,```!!````
M*0```$$````"````00```!D```!!````"@```$$````+````00``````````
M````)7,O)7,```!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N
M86QS.CI005(Z.D)/3U0`````+W!R;V,O)6DO)7,`97AE`"X```!005)?5$5-
M4`````!005)?4%)/1TY!344`````.@```"5S)7,E<P``+P```%!%4DPU3$E"
M`````%!%4DQ,24(`4$523#5/4%0`````4$523$E/``!005)?24Y)5$E!3$E:
M140`4$%27U-005=.140`4$%27T-,14%.````4$%27T1%0E5'````4$%27T-!
M0TA%````4$%27T=,3T)!3%]$14)51P````!005)?1TQ/0D%,7U1-4$1)4@``
M`%!!4E]435!$25(``%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,7T-,14%.
M`````&QS965K(&9A:6QE9`````!R96%D(&9A:6QE9`!,1%],24)205)97U!!
M5$@`4UE35$5-```E,#)X`````"5S)7,E<R5S`````'!A<BT`````)7,Z(&-R
M96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R
M;F\])6DI"@``)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F
M92`H<&QE87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI
M"@``4$%42`````!P87)L`````"YP87(`````<VAO<G0@<F5A9```)7,E<V-A
M8VAE+25S)7,``"5S)7-T96UP+25U)7,````E<R5S=&5M<"TE=2TE=25S````
M`!@```!P97)L`````#````!005(Z.E!A8VME<CHZ5D524TE/3@`````Q+C`V
M,0```%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y`````"5S.B!C
M<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL
M960@*&5R<FYO/25I*0H`````+64``"TM``!54T52`````%5315).04U%````
M`%1%35!$25(`5$U0`"]T;7``````979A;"`G97AE8R`O=7-R+V)I;B]P97)L
M("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@
M<V]M92!S:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H)%!!4E]-04=)0RP@
M)$9)3$5?;V9F<V5T7W-I>F4L("1C86-H95]N86UE7W-I>F4I.PI"14=)3B![
M"B1005)?34%'24,@/2`B7&Y005(N<&U<;B(["B1&24Q%7V]F9G-E=%]S:7IE
M(#T@-#L@("`C('!A8VLH(DXB*0HD8V%C:&5?;F%M95]S:7IE(#T@-#`["B10
M2UI)4%]-04=)0R`](")02UPP,#-<,#`T(CL*?0IS=6(@9FEN9%]P87)?;6%G
M:6,*>PIM>2`H)&9H*2`]($!?.PIM>2`D8VAU;FM?<VEZ92`](#8T("H@,3`R
M-#L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D9F@["FUY("1P;W,@/2`H)'-I
M>F4M,2D@+2`H)'-I>F4M,2D@)2`D8VAU;FM?<VEZ93L@("`@("`C($Y/5$4Z
M("1P;W,@:7,@82!M=6QT:7!L92!O9B`D8VAU;FM?<VEZ90IW:&EL92`H)'!O
M<R`^/2`P*2!["G-E96L@)&9H+"`D<&]S+"`P.PIR96%D("1F:"P@)&)U9BP@
M)&-H=6YK7W-I>F4@*R!L96YG=&@H)%!!4E]-04=)0RD["FEF("@H;7D@)&D@
M/2!R:6YD97@H)&)U9BP@)%!!4E]-04=)0RDI(#X](#`I('L*<F5T=7)N("1P
M;W,@*R`D:3L*?0HD<&]S("T]("1C:'5N:U]S:7IE.PI]"G)E='5R;B`M,3L*
M?0IM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE+"`E36]D=6QE
M0V%C:&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@
M1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&
M:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA
M;64H)'!A<E]T96UP*3L*;W5T<RAQ<5M296UO=FEN9R!F:6QE<R!I;B`B)'!A
M<E]T96UP(ETI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I
M(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T
M96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*
M;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]/B`G=&UP6%A8
M6%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL
M"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIM>2`D9FEL96YA
M;64@/2`D=&UP+3YF:6QE;F%M93L*<')I;G0@)'1M<"`\/"(N+BXB.PIX/3$[
M('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*
M:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P
M(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<D9FEL96YA;64G"BXN+@IC
M;&]S92`D=&UP.PIC:&UO9"`P-S`P+"`D9FEL96YA;64["FUY("1C;60@/2`B
M)&9I;&5N86UE(#XO9&5V+VYU;&P@,CXF,2`F(CL*<WES=&5M*"1C;60I.PIO
M=71S*'%Q6U-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@
M8VQE86YU<#H@)&9I;&5N86UE72D["GT*?2!]"D)%1TE.('L*26YT97)N86QS
M.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/
M5#L*979A;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U:65T(#T@(21%3E9[
M4$%27T1%0E5'?3L*;7D@)7-Y<R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]
M?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@
M/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D
M96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O
M)RDL"BD["E]S971?<')O9VYA;64H*3L*;W5T<RAQ<5M<)'!R;V=N86UE(#T@
M(B1P<F]G;F%M92)=*3L*7W-E=%]P87)?=&5M<"@I.PIO=71S*'%Q6UPD14Y6
M>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2)=*3L*;7D@*"1S=&%R=%]P
M;W,L("1S=&%R=%]O9E]&24Q%7W-E8W1I;VXI.PI-04=)0SH@>PIL;V-A;"`D
M4TE'>U]?5T%23E]??2`]('-U8B![?3L*=6YL97-S("AO<&5N(%]&2"P@)SPZ
M<F%W)RP@)'!R;V=N86UE*2!["F]U=',H<7%;0V%N)W0@<F5A9"!F<F]M(&9I
M;&4@(B1P<F]G;F%M92)=*3L@(",@9&]N)W0@=7-E("0A(&AE<F4@87,@:70@
M<F5Q=6ER97,@17)R;F\N<&T*;&%S="!-04=)0SL*?0IM>2`D;6%G:6-?<&]S
M(#T@9FEN9%]P87)?;6%G:6,H*E]&2"D["FEF("@D;6%G:6-?<&]S(#P@,"D@
M>PIO=71S*'%Q6T-A;B=T(&9I;F0@;6%G:6,@<W1R:6YG("(D4$%27TU!1TE#
M(B!I;B!F:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'24,["GT*;W5T<R@B
M1F]U;F0@4$%2(&UA9VEC(&%T('!O<VET:6]N("1M86=I8U]P;W,B*3L*<V5E
M:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92`M(&QE;F=T
M:"@B7#!#04-(12(I+"`P.PIR96%D(%]&2"P@)&)U9BP@;&5N9W1H*")<,$-!
M0TA%(BD["FEF("@D8G5F(&YE(")<,$-!0TA%(B`F)B`D8G5F(&YE(")<,$-,
M14%.(BD@>PIO=71S*").;R!C86-H92!M87)K97(@9F]U;F0B*3L*;&%S="!-
M04=)0SL*?0IO=71S*'%Q6T-A8VAE(&UA<FME<B`B)&)U9B(@9F]U;F1=*3L*
M<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92P@,#L*
M<F5A9"!?1D@L("1B=68L("1&24Q%7V]F9G-E=%]S:7IE.PIM>2`D;V9F<V5T
M(#T@=6YP86-K*").(BP@)&)U9BD["F]U=',H(D]F9G-E="!F<F]M('-T87)T
M(&]F($9)3$5S(&ES("1O9F9S970B*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@
M+2`D1DE,15]O9F9S971?<VEZ92`M("1O9F9S970L(#`["B1S=&%R=%]O9E]&
M24Q%7W-E8W1I;VX@/2!T96QL(%]&2#L*;7D@)7)E<75I<F5?;&ES=#L*<F5A
M9"!?1D@L("1B=68L(#0[("`@("`@("`@("`@("`@("`@("`@("`@("`@(R!R
M96%D('1H92!F:7)S="`B1DE,12(*=VAI;&4@*"1B=68@97$@(D9)3$4B*2![
M"G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").
M(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U=',H<7%;56YP86-K
M:6YG($9)3$4@(B1F=6QL;F%M92(N+BY=*3L*;7D@)&-R8R`]("@@)&9U;&QN
M86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*;7D@
M*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<
M+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N
M<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A
M?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I;&5N86UE(#T@7W-A
M=F5?87,H(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE879Y.CI&
M=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ
M.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L<V4@>PHD
M36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]
M/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*)')E<75I<F5?;&ES='LD
M9G5L;&YA;65]*RL["GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.
M0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I
M9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&EN9F\@/2`D36]D=6QE
M0V%C:&5[)&UO9'5L97T["G)E='5R;B!U;FQE<W,@)&EN9F\["F1E;&5T92`D
M<F5Q=6ER95]L:7-T>R1M;V1U;&5].PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D
M97(O)&EN9F\O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E
M9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN
M97=?=&UP9FEL92!O<B!D:64@(D-A;B=T(&-R96%T92!T96UP(&9I;&4Z("0A
M(CL*)&9H+3YB:6YM;V1E*"D["B1F:"T^<')I;G0H)&EN9F\M/GMB=69]*3L*
M)&9H+3YS965K*#`L(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D9FEL
M96YA;64@/2!?<V%V95]A<R@B)&EN9F\M/GMC<F-]+G!M(BP@)&EN9F\M/GMB
M=69]*3L*)&EN9F\M/GMF:6QE?2`]("1F:6QE;F%M93L*;W!E;B!M>2`D9F@L
M("<\.G)A=R<L("1F:6QE;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I
M;&5N86UE(CH@)"%=.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN
M9R!F86EL960Z(&-A;B=T(&9I;F0@;6]D=6QE("1M;V1U;&4A(CL*?2P@0$E.
M0RD["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q
M=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!
M4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL
M93L*=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?
M;&ES="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N
M86UE(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O
M:2D@>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE
M('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*
M?0ID96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]"FEF("@D8G5F
M(&YE("102UI)4%]-04=)0RD@>PIO=71S*'%Q6TYO('II<"!F;W5N9"!A9G1E
M<B!&24Q%('-E8W1I;VX@:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!
M1TE#(#L*?0HD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0[("`@("`@("`@
M("`@("`@(",@<W1A<G0@;V8@>FEP"GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U
M="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T92`D14Y6
M>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M87D@8F4@82!S
M96-U<FET>2!P<F]B;&5M*0II9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=
M(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD
M(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N
M:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF
M("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!
M4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS
M92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW
M:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4
M=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?
M=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D
M,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@
M)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@
M*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E
M<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I
M('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO
M9V9H+"`B/CXB+"`D,B!O<B!D:64@<7%;0V%N)W0@;W!E;B!L;V<@9FEL92`B
M)#(B.B`D(5T["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]
M("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[
M)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR
M97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE
M<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8[
M"F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@
M*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z
M.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D<&%R(#T@<VAI9G0H
M0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@
M)&9H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!F:6YD('!A<B!F
M:6QE("(D<&%R(CH@)"%=.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP
M(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N
M9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@
M9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P87(B73L*?0IM
M>2`E;65T85]P87(@/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z
M:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R
M.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;
M7CI=*RDZ("@N*RDD+VUG.PI]"GT["FEF("AD969I;F5D("1P87(I('L*;W!E
M;B!M>2`D<&@L("<\.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T(')E860@
M<&%R(&9I;&4@(B1P87(B.B`D(5T["FUY("1B=68["G)E860@)'!H+"`D8G5F
M+"`T.PID:64@<7%;(B1P87(B(&ES(&YO="!A('!A<B!F:6QE72!U;FQE<W,@
M)&)U9B!E<2`D4$M:25!?34%'24,["F-L;W-E("1P:#L*?0I#<F5A=&50871H
M*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I
M;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U)$5U(H*2!\($E/.CI&:6QE
M.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE('%Q6T-A;B=T(&-R96%T92!F
M:6QE("(D;W5T(CH@)"%=.PHD9F@M/F)I;FUO9&4H*3L*<V5E:R!?1D@L(#`L
M(#`["FUY("1L;V%D97(["FEF("AD969I;F5D("1S=&%R=%]O9E]&24Q%7W-E
M8W1I;VXI('L*<F5A9"!?1D@L("1L;V%D97(L("1S=&%R=%]O9E]&24Q%7W-E
M8W1I;VX["GT@96QS92!["FQO8V%L("0O(#T@=6YD968["B1L;V%D97(@/2`\
M7T9(/CL*?0II9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]
M?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D
M4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1L;V%D97(L
M("0P*3L*?0HD9F@M/G!R:6YT*"1L;V%D97(I"F]R(&1I92!Q<5M%<G)O<B!W
M<FET:6YG(&QO861E<B!T;R`B)&]U="(Z("0A73L*:68@*"1B=6YD;&4I('L*
M<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A
M9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC
M(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G<VET
M92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD
M"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*
M<WPO*WPO?&<L('-\+R1\?"!F;W)E86-H($!I;F,["FUY("5F:6QE<SL*)&9I
M;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L
M('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML
M:6)?97AT?3L@("`@("`@("`C(%A86"!L:6)?97AT('9S(&1L97AT(#\*;7D@
M)7=R:71T96X["F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5F:6QE<RD@
M>PIM>2`H)&9I;&4L("1N86UE*3L*:68@*&1E9FEN960H;7D@)&9C(#T@)%!!
M4CHZ2&5A=GDZ.D9U;&Q#86-H97LD:V5Y?2DI('L**"1F:6QE+"`D;F%M92D@
M/2`H)&ME>2P@)&9C*3L*?0IE;'-E('L*9F]R96%C:"!M>2`D9&ER("A`:6YC
M*2!["FEF("@D:V5Y(#U^(&U\7EQ1)&1I<EQ%+R@N*BDD?&DI('L**"1F:6QE
M+"`D;F%M92D@/2`H)&ME>2P@)#$I.PIL87-T.PI]"FEF("@D:V5Y(#U^(&U\
M7B]L;V%D97(O6UXO72LO*"XJ*21\*2!["FEF("AM>2`D<F5F(#T@)$UO9'5L
M94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA
M<W0["GT*:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B
M)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*?0IN97AT('5N;&5S<R!D969I
M;F5D("1N86UE.PIN97AT(&EF("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF
M("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+VD[
M"F]U=',H<W!R:6YT9BAQ<5M086-K:6YG($9)3$4@(B5S(BXN+ETL(')E9B`D
M9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92DI.PIM>2`D8V]N=&5N=#L*
M:68@*')E9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*
M96QS92!["FQO8V%L("0O(#T@=6YD968["F]P96X@;7D@)'1H+"`G/#IR87<G
M+"`D9FEL92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&4B.B`D(5T["B1C
M;VYT96YT(#T@/"1T:#X["F-L;W-E("1T:#L*4$%2.CI&:6QT97(Z.E!O9%-T
M<FEP+3YA<'!L>2A<)&-O;G1E;G0L("(\96UB961D960^+R1N86UE(BD*:68@
M(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\
M86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY
M*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0HD9F@M/G!R:6YT*")&24Q%
M(BP*<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2P*<W!R:6YT9B@B)3`X
M>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@
M)&YA;64I+`IP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DL"B1C;VYT96YT
M*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!E;6)E9&1E9"!&24Q%('1O("(D
M;W5T(CH@)"%=.PIO=71S*'%Q6U=R:71T96X@87,@(B1N86UE(ETI.PI]"GT*
M:68@*"1Z:7`I('L*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2`]/2!!
M<F-H:79E.CI::7`Z.D%:7T]+"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('II
M<"!P87)T(&]F("(D;W5T(ET["GT*:68@*"1M971A7W!A<GMC;&5A;GTI('L*
M)&9H+3YP<FEN="@B7#!#3$5!3B(I.PI]"F5L<V4@>PII9B`H(61E9FEN960@
M)&-A8VAE7VYA;64I('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D[
M"G-E96L@)&9H+"`P+"`P.PHD8W1X+3YA9&1F:6QE*"1F:"D["G-E96L@)&9H
M+"`P+"`R.PHD8V%C:&5?;F%M92`]("1C='@M/FAE>&1I9V5S=#L*?0HD8V%C
M:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@)&-A8VAE7VYA;65?
M<VEZ93L*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@D8V%C:&5?;F%M95]S:7IE
M("T@;&5N9W1H("1C86-H95]N86UE*3L*)&9H+3YP<FEN="@D8V%C:&5?;F%M
M92P*(EPP0T%#2$4B*3L*?0IM>2`D;V9F<V5T(#T@)&9H+3YT96QL("T@;&5N
M9W1H*"1L;V%D97(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D;V9F<V5T*2P*
M)%!!4E]-04=)0RD["B1F:"T^8VQO<V4@;W(@9&EE('%Q6T5R<F]R('=R:71I
M;F<@=')A:6QE<B!O9B`B)&]U="(Z("0A73L*8VAM;V0@,#<U-2P@)&]U=#L*
M97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I
M>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?
M9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!
M<F-H:79E.CI::7`["GT*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(",@07)C:&EV93HZ6FEP(&]P97)A=&5S
M(&]N(&%N($E/.CI(86YD;&4*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R
M)RD@;W(@9&EE('%Q6V9D;W!E;B@I(&9A:6QE9#H@)"%=.PI!<F-H:79E.CI:
M:7`Z.G-E=$-H=6YK4VEZ92@M<R!?1D@I.PIM>2`D>FEP(#T@07)C:&EV93HZ
M6FEP+3YN97<["B@D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O
M9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2D*;W(@9&EE('%Q6T5R
M<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P<F]G;F%M92)=.PI!<F-H:79E
M.CI::7`Z.G-E=$-H=6YK4VEZ92@V-"`J(#$P,C0I.PIP=7-H($!005(Z.DQI
M8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II
M<#L*;W5T<R@B17AT<F%C=&EN9R!Z:7`N+BXB*3L*:68@*&1E9FEN960@)$5.
M5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A
M"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@
M:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M
M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@
M;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_
M"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S
M=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@
M)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@
M)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H<7%;4VMI<'!I
M;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@
M(B1D97-T7VYA;64B72D["GT@96QS92!["F]U=',H<7%;17AT<F%C=&EN9R`B
M)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(N+BY=*3L**"1M96UB97(M
M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*2`]/2!!<F-H:79E.CI:
M:7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!E>'1R86-T:6YG('II<"!M
M96UB97(@=&\@(B1D97-T7VYA;64B73L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M
M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI
M8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8[
M"E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE
M(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM
M3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O
M9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"![
M"FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@
M*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I
M;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@[
M"D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@
M(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE
M<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@
M:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E
M<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y
M.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q
M=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI4
M96UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E
M<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z
M.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV
M93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PIR97%U:7)E(%!!4CL*<F5Q
M=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!0
M05(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A
M=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER
M92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*979A;"![(')E<75I
M<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N
M>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D
M0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R
M;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@=71F."!].PI]"G-U8B!?
M<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD
M("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*
M<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q
M=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H
M($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D969I;F5D("1P
M871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M93L*
M;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D
M969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@
M*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD
M969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U:60["GT*96QS92![
M"B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@
M)U-94U1%32<["GT*;7D@)'-T;7!D:7(@/2`B)'!A=&@D<WES>U]D96QI;7UP
M87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L
M(#`W-34["FUY("1C86-H95]D:7(["FEF("@D14Y6>U!!4E]#3$5!3GTI('L*
M)&-A8VAE7V1I<B`](")T96UP+20D(CL*?0IE;'-E('L*;W!E;B!M>2`D9F@L
M("(\.G)A=R(L("1P<F]G;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)'!R
M;V=N86UE(CH@)"%=.PII9B`H*&UY("1M86=I8U]P;W,@/2!F:6YD7W!A<E]M
M86=I8R@D9F@I*2`^/2`P*2!["G-E96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)
M3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*;7D@)&)U
M9CL*<F5A9"`D9F@L("1B=68L(&QE;F=T:"@B7#!#04-(12(I.PII9B`H)&)U
M9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,
M15]O9F9S971?<VEZ90HM(&QE;F=T:"@B7#!#04-(12(I"BT@)&-A8VAE7VYA
M;65?<VEZ92P@,#L*<F5A9"`D9F@L("1B=68L("1C86-H95]N86UE7W-I>F4[
M"B1B=68@/7X@<R]<,"\O9SL*)&-A8VAE7V1I<B`](")C86-H92TD8G5F(CL*
M?0I]"F-L;W-E("1F:#L*?0II9B`H(21C86-H95]D:7(I('L*)&-A8VAE7V1I
M<B`](")T96UP+20D(CL*)$5.5GM005)?0TQ%04Y](#T@,3L*?0HD<W1M<&1I
M<B`N/2`B)'-Y<WM?9&5L:6U])&-A8VAE7V1I<B(["FUK9&ER("1S=&UP9&ER
M+"`P-S4U.PHD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIL87-T.PI]"B1P
M87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]4
M14U0?2`]?B`O*"XK*2\["GT*<W5B(%]S879E7V%S('L*;7D@*"1N86UE+"`D
M8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T
M96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N
M86UE(#T@(B1F=6QL;F%M92XD)"(["FUY("1F:#L**&]P96X@)&9H+"`G/CIR
M87<G+"`D=&5M<&YA;64I"B8F("AP<FEN="`D9F@@)&-O;G1E;G1S*0HF)B`H
M8VQO<V4@)&9H*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R`B)'1E;7!N86UE
M(CH@)"%=.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN960@)&UO
M9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL:6YK*"1T
M96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E=%]P<F]G
M;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.
M5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*
M?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN
M9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N
M86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)'-Y
M<WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R
M(&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`^/2`P*2!["FEF("AO
M<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F
M:#L*?0II9B`H+7,@(B1P<F]G;F%M921S>7-[7V5X97TB*2!["B1P<F]G;F%M
M92`N/2`D<WES>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@
M*'-P;&ET("]<421S>7-[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE
M>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[
M4$%27U1%35!].PHD9&ER(#U^(',O7%$D<WES>U]D96QI;7U<120O+SL**"@D
M<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X
M97TB*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D
M<WES>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P
M<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P<F]G
M;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE
M('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L
M("1S>7-[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)'-Y<WM?9&5L
M:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T
M8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#
M=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*
M)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D<WES>U]D96QI;7U<12DO)'!W
M9"1S>7-[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M
M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!
M3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])
M3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!
M3B!$14)51R!#04-(12!04D]'3D%-12`I("D@>PID96QE=&4@)$5.5GLB4$%2
M7R1?(GT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@
M>PHD14Y6>R)005)?)%\B?2`]("1%3E9[(E!!4E]'3$]"04Q?)%\B?2!I9B!E
M>&ES=',@)$5.5GLB4$%27T=,3T)!3%\D7R)].PI]"FEF("@D14Y6>U!!4E]4
M14U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]"GT*<W5B(&]U=',@
M>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F
M:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET
M7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE
M9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R
M:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP
M('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005([
M"G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`
M<&%R7V%R9W,I.PID:64@<7%;<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R
M:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&Y=
M"G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI
M="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`
M(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI
M="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I
M.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@!P
M97)L>'-I+F,`````0T%#2$4``#X```!!````#````$$````1````00```"<`
M``!!````-@```$$````#````00````8```!!````%0```$$````/````00``
M``X```!!````)@```$$````3````00```"D```!!`````@```$$````9````
M00````H```!!````"P```$$`````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````#H%P``4!<```$````=`P```0``
M`"@#```=````?`0```P```!X$```#0````!(```9````R)T``!L````$````
M&@```,R=```<````!````/7^_V]P`0``!0````P)```&````7`(```H```":
M!```"P```!`````5``````````,```#`G@```@```.`!```4````$0```!<`
M``"8#@``$0```*@-```2````\````!,````(````'@````@```#[__]O`0``
M"/K__V\0````````````````````````````````````````````````````
M`````-"=`````````````(00``"$$```A!```(00``"$$```A!```(00``"$
M$```A!```(00``"$$```A!```(00``"$$```A!```(00``"$$```A!```(00
M``"$$```A!```(00``"$$```A!```(00``"$$```A!```(00``"$$```A!``
M`(00``"$$```A!```(00``"$$```A!```(00``"$$```A!```(00``"$$```
MA!```(00``"$$```A!```(00``"$$```A!```(00``"$$```A!```(00``"$
M$```A!```(00``"$$```A!```(00``"$$```A!```&@3``````````````!(
M`````````````'@0````````````````````````````````````````````
M`````````````*````I005(N<&T*`````-!+``#H2````````*A)``"L20``
MQ$L``/!(``#,2P```````+!+``"X2P```````-A+``!'0T,Z("A!;'!I;F4@
M,3,N,BXQ7V=I=#(P,C,Q,#$T*2`Q,RXR+C$@,C`R,S$P,30`03(```!A96%B
M:0`!*`````4V2UH`!@<(`0D!"@(2!!,!%`$5`1<#&`$:`AP!'@(B`40!`"YS
M:'-T<G1A8@`N:6YT97)P`"YN;W1E+F=N=2YB=6EL9"UI9``N9VYU+FAA<V@`
M+F1Y;G-Y;0`N9'EN<W1R`"YR96PN9'EN`"YR96PN<&QT`"YI;FET`"YT97AT
M`"YF:6YI`"YR;V1A=&$`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R
M<F%Y`"YD>6YA;6EC`"YG;W0`+F1A=&$`+F)S<P`N8V]M;65N=``N05)-+F%T
M=')I8G5T97,`````````````````````````````````````````````````
M``````L````!`````@```#0!```T`0``&````````````````0`````````3
M````!P````(```!,`0``3`$``"0```````````````0`````````)@```/;_
M_V\"````<`$``'`!``#L````!``````````$````!````#`````+`````@``
M`%P"``!<`@``L`8```4````#````!````!`````X`````P````(````,"0``
M#`D``)H$``````````````$`````````0`````D````"````J`T``*@-``#P
M````!``````````$````"````$D````)````0@```)@.``"8#@``X`$```0`
M```1````!`````@```!2`````0````8```!X$```>!````P`````````````
M``0`````````30````$````&````A!```(00``#D`@`````````````$````
M!````%@````!````!@```&@3``!H$P``F#0`````````````"`````````!>
M`````0````8`````2````$@```P```````````````0`````````9`````$`
M```"````#$@```Q(``#@00`````````````$`````````&P````!`````@``
M`.R)``#LB0``!```````````````!`````````!V````#@````,```#(G0``
MR(T```0```````````````0````$````@@````\````#````S)T``,R-```$
M```````````````$````!````(X````&`````P```-"=``#0C0``\`````4`
M````````!`````@```"7`````0````,```#`G@``P(X``$`!````````````
M``0````$````G`````$````#`````*````"0``!$```````````````$````
M`````*(````(`````P```$2@``!$D```+```````````````!`````````"G
M`````0```#``````````1)```#$```````````````$````!````L`````,`
M`'```````````'60```S```````````````!``````````$````#````````
=``````"HD```P````````````````0``````````
